#!/usr/bin/env python3
#!coding=utf-8

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

import sys

def main():

    print('t3cl :: Work in progress')

    return 0

if __name__ == '__main__':
    sys.exit(main())
