#!coding=utf-8

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

__all__ = [
    '__title__', '__summary__', '__url__', '__version__',
    '__author__', '__email__', '__license__', '__copyright__',
]

__title__ = 't3cl'
__summary__ = 'TTCN-3 Code Linter'
__url__ = 'https://github.com/kprzybyla/t3cl'
__version__ = '0.0.1'
__author__ = 'Krzysztof Przybyła'
__email__ = 'krzysztof.h.przybyla@gmail.com'
__license__ = 'Mozilla Public License Version 2.0'
__copyright__ = '2017 {AUTHOR}'.format(AUTHOR = __author__)
