#!coding=utf-8

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

__all__ = [
    '__title__', '__summary__', '__url__', '__version__',
    '__author__', '__email__', '__license__', '__copyright__',
]

from t3cl.__about__ import *
